@@ -1,12 +1,12 @@
 """Lilv Python interface"""
 
-# Copyright 2016-2022 David Robillard <d@drobilla.net>
+# Copyright 2016-2025 David Robillard <d@drobilla.net>
 # SPDX-License-Identifier: ISC
 
 __author__ = "David Robillard"
-__copyright__ = "Copyright 2016-2024 David Robillard"
+__copyright__ = "Copyright 2016-2025 David Robillard"
 __license__ = "ISC"
-__version__ = "0.24.26"
+__version__ = "0.26.2"
 __maintainer__ = "David Robillard"
 __email__ = "d@drobilla.net"
 __status__ = "Production"
@@ -19,8 +19,11 @@ from ctypes import c_char, c_char_p, c_void_p
 from ctypes import byref, cast
 
 # Option constants
-OPTION_FILTER_LANG = "http://drobilla.net/ns/lilv#filter-lang"
 OPTION_DYN_MANIFEST = "http://drobilla.net/ns/lilv#dyn-manifest"
+OPTION_FILTER_LANG = "http://drobilla.net/ns/lilv#filter-lang"
+OPTION_LANG = "http://drobilla.net/ns/lilv#lang"
+OPTION_LV2_PATH = "http://drobilla.net/ns/lilv#lv2-path"
+OPTION_OBJECT_INDEX = "http://drobilla.net/ns/lilv#object-index"
 
 
 class _LilvLib:
@@ -1209,8 +1212,11 @@ class World(Structure):
         """Set a world option.
 
         Currently recognized options:
-        lilv.OPTION_FILTER_LANG
         lilv.OPTION_DYN_MANIFEST
+        lilv.OPTION_FILTER_LANG
+        lilv.OPTION_LANG
+        lilv.OPTION_LV2_PATH
+        lilv.OPTION_OBJECT_INDEX
         """
         return c.world_set_option(self.world, uri, value.node)
 
@@ -1873,5 +1879,5 @@ LILV_URI_INPUT_PORT = "http://lv2plug.in/ns/lv2core#InputPort"
 LILV_URI_MIDI_EVENT = "http://lv2plug.in/ns/ext/midi#MidiEvent"
 LILV_URI_OUTPUT_PORT = "http://lv2plug.in/ns/lv2core#OutputPort"
 LILV_URI_PORT = "http://lv2plug.in/ns/lv2core#Port"
-LILV_OPTION_FILTER_LANG = "http://drobilla.net/ns/lilv#filter-lang"
 LILV_OPTION_DYN_MANIFEST = "http://drobilla.net/ns/lilv#dyn-manifest"
+LILV_OPTION_FILTER_LANG = "http://drobilla.net/ns/lilv#filter-lang"
